@@ -18,11 +18,9 @@
  */
 
 #include <biometry/qml/Biometryd/identifier.h>
-#include <biometry/qml/Biometryd/user.h>
 
 #include <biometry/application.h>
 #include <biometry/reason.h>
-#include <biometry/user.h>
 
 /// @brief Identifier initializes a new instance with impl and parent.
 biometry::qml::Identifier::Identifier(const std::reference_wrapper<biometry::Identifier>& impl, QObject* parent)
